# Mirascope Core

This section provides a reference for the core functionality of Mirascope. It breaks down into a section for the base functionality that is agnostic to each provider as well as the modules we've implemented for each of the providers that we support.
